from __future__ import annotations

from .biliass import (
    Danmaku2ASS as Danmaku2ASS,
    ReadCommentsBilibiliProtobuf as ReadCommentsBilibiliProtobuf,
    ReadCommentsBilibiliXml as ReadCommentsBilibiliXml,
)

__version__ = "1.3.12"



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: protobuf/danmaku.proto
# Protobuf Python Version: 5.28.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    28,
    0,
    '',
    'protobuf/danmaku.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x16protobuf/danmaku.proto\"\xba\x01\n\x0b\x44\x61nmakuElem\x12\n\n\x02id\x18\x01 \x01(\x03\x12\x10\n\x08progress\x18\x02 \x01(\x05\x12\x0c\n\x04mode\x18\x03 \x01(\x05\x12\x10\n\x08\x66ontsize\x18\x04 \x01(\x05\x12\r\n\x05\x63olor\x18\x05 \x01(\r\x12\x10\n\x08mid_hash\x18\x06 \x01(\t\x12\x0f\n\x07\x63ontent\x18\x07 \x01(\t\x12\r\n\x05\x63time\x18\x08 \x01(\x03\x12\x0e\n\x06\x61\x63tion\x18\t \x01(\t\x12\x0c\n\x04pool\x18\n \x01(\x05\x12\x0e\n\x06id_str\x18\x0b \x01(\t\"+\n\x0c\x44\x61nmakuEvent\x12\x1b\n\x05\x65lems\x18\x01 \x03(\x0b\x32\x0c.DanmakuElemb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'protobuf.danmaku_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_DANMAKUELEM']._serialized_start=27
  _globals['_DANMAKUELEM']._serialized_end=213
  _globals['_DANMAKUEVENT']._serialized_start=215
  _globals['_DANMAKUEVENT']._serialized_end=258
# @@protoc_insertion_point(module_scope)
